@@ -3,8 +3,10 @@
 {
     'name': 'Stock Location Sequence',
     'name_de_DE': 'Lagerverwaltung Lagerortsequenz',
+    'name_es_CO': 'Secuencia de Sitio del Stock',
+    'name_es_ES': 'Secuencia de ubicación de existencias',
     'name_fr_FR': 'Séquence emplacement',
-    'version': '1.2.0',
+    'version': '1.4.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -12,6 +14,9 @@
 ''',
     'description_de_DE': '''Fügt dem Objekt Lagerort eine Sequenz hinzu
 ''',
+    'description_es_CO': '''Añade una secuencia e sitio a un objeto
+''',
+    'description_es_ES': 'Añade una secuencia al objeto ubicación',
     'description_fr_FR': '''Ajoute une séquence sur le modèle emplacement
 ''',
     'depends': [
@@ -23,6 +28,8 @@
     ],
     'translation': [
         'de_DE.csv',
+        'es_CO.csv',
+        'es_ES.csv',
         'fr_FR.csv',
     ],
 }
